@@ -39,15 +39,15 @@ doctor_cppcode <- function(stanc_ret,
     stop("'includes_for_user_defined_functions' must be a character vector, possibly of length zero")
   if (!is.character(friends))
     stop("'friends' must be a (possibly empty) character vector")
-  
-  if (!is.list(stanc_ret) || is.null(stanc_ret$cppcode) || 
+
+  if (!is.list(stanc_ret) || is.null(stanc_ret$cppcode) ||
       !is.character(stanc_ret$cppcode))
     stop("'stanc_ret' must be a list (like) that is returned by 'stanc'")
-  
+
   valid <- "[ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789_]"
-  
+
   lines <- scan(what = character(), sep = "\n", quiet = TRUE, text = stanc_ret$cppcode)
-  
+
   check_logical_scalar_first <- function(x, na_ok = FALSE) {
     end <- if (na_ok) "must be TRUE, FALSE, or NA" else "must be either TRUE or FALSE"
     msg <- paste(deparse(substitute(x)), end)
@@ -55,36 +55,36 @@ doctor_cppcode <- function(stanc_ret,
     if (!na_ok && is.na(x)) stop(msg)
     x
   }
-  
+
   four_spaces <- "    "
   protected <- list()
-  
+
   if (check_logical_scalar_first(use_R_PRNG)) {
-    protected$PRNG <- paste0(four_spaces, 
+    protected$PRNG <- paste0(four_spaces,
                              "boost_random_R base_rng__ = boost_random_R();")
   } else { # this could be dangerous to use with parallel chains
     protected$PRNG <- paste0(four_spaces,
                              "mutable boost::ecuyer1988 base_rng__;")
   }
-  
+
   if (check_logical_scalar_first(use_Rcout)) {
     pstream__ <- "&Rcpp::Rcout"
     lines <- gsub("std::ostream* pstream__ = 0", "std::ostream* pstream__ = &Rcpp::Rcout",
                   lines, fixed = TRUE)
-    lines <- gsub("std::ostream* pstream__) const {", 
+    lines <- gsub("std::ostream* pstream__) const {",
                   "std::ostream* pstream__ = &Rcpp::Rcout) const {",
                   lines, fixed = TRUE)
   } else {
     pstream__ <- "nullptr"
     lines <- gsub("std::ostream* pstream__ = 0", "std::ostream* pstream__ = nullptr",
                   lines, fixed = TRUE)
-    lines <- gsub("std::ostream* pstream__) const {", 
+    lines <- gsub("std::ostream* pstream__) const {",
                   "std::ostream* pstream__ = nullptr) const {",
                   lines, fixed = TRUE)
   }
   protected$pstream <- paste0(four_spaces, "std::ostream* pstream__ = ",
                               pstream__, ";")
-  
+
   if (check_logical_scalar_first(promote_args_to_auto)) {
     lines <- gsub("typename boost::math::tools::promote_args<.*$", "auto", lines)
     lines <- gsub("typedef typename boost::math::tools::promote_args<(.*)>.* ",
@@ -92,14 +92,14 @@ doctor_cppcode <- function(stanc_ret,
     mark <- grep("typedef decltype", lines)
     lines[mark] <- gsub(", ", " + ", lines[mark], fixed = TRUE)
   }
-  
+
   if (check_logical_scalar_first(detemplate)) {
     if (length(friends) > 0L)
       stop("cannot 'detemplate' the C++ code if 'friends' is specified")
     mark <- grep("template <", lines, fixed = TRUE)
     for (m in rev(mark)) # cannot actually detemplate the RNG for some reason
       if (!grepl("template <typename RNG>", lines[m], fixed = TRUE)) lines <- lines[-m]
-      
+
       if (!isTRUE(double_only)) {
         double_only <- TRUE
         message("'double_only' changed to TRUE due to 'detemplate' being TRUE")
@@ -115,15 +115,15 @@ doctor_cppcode <- function(stanc_ret,
   } else {
     lines <- gsub("typename T__>$", "typename T__ = double>", lines)
     lines <- gsub("typename T_>$",  "typename T_ = double>",  lines)
-    lines <- gsub("typename T([[:digit:]]+)__", 
+    lines <- gsub("typename T([[:digit:]]+)__",
                   "typename T\\1__ = double", lines)
     lines <- gsub("typename T_lp__", "T_lp__ = double", lines)
     lines <- gsub("typename T_lp_accum__", "typename T_lp_accum__ = double", lines)
-    lines <- gsub("Class RNG", 
+    lines <- gsub("Class RNG",
                   paste0("Class RNG = ", ifelse(use_R_PRNG, "boost_random_R",
                                                 "boost::ecuyer1988")), lines)
   }
-  
+
   if (check_logical_scalar_first(double_only)) {
     if (!detemplate)
       stop("if 'double_only' is TRUE, then 'detemplate' must also be TRUE")
@@ -131,13 +131,13 @@ doctor_cppcode <- function(stanc_ret,
     lines <- gsub("T_lp__", "double", lines)
     lines <- gsub("T[[:digit:]]*_+", "double", lines)
   }
-  
+
   if (check_logical_scalar_first(propto__) || !propto__) {
     if (!detemplate) {
-      lines <- gsub("bool propto__", 
+      lines <- gsub("bool propto__",
                     paste("bool propto__ =", ifelse(propto__, "true", "false")),
                     lines, fixed = TRUE)
-      lines <- gsub("bool propto,", 
+      lines <- gsub("bool propto,",
                     paste("bool propto =", ifelse(propto__, "true,", "false,")),
                     lines, fixed = TRUE)
       mark <- grep("const static bool propto", lines)
@@ -150,7 +150,7 @@ doctor_cppcode <- function(stanc_ret,
                                  ifelse(propto__, "true", "false"), ";")
     }
   }
-  
+
   if (check_logical_scalar_first(jacobian__) || !jacobian__) {
     if (!detemplate) {
       lines <- gsub("bool jacobian__",
@@ -167,18 +167,18 @@ doctor_cppcode <- function(stanc_ret,
                                    ifelse(jacobian__, "true", "false"), ";")
     }
   }
-  
+
   if (check_logical_scalar_first(default_constructor)) {
     if (!isTRUE(make_data_public)) {
       make_data_public <- TRUE
       message("'make_data_public' changed to TRUE due to 'default_constructor' being TRUE")
     }
   }
-  
+
   if (check_logical_scalar_first(make_data_public)) {
     lines <- sub("^private:", "public:", lines)
   }
-  
+
   find_closing <- function(lines, mark) {
     if (length(mark) != 1 || is.na(mark)) stop("mark is wrong")
     opening <- lines[mark]
@@ -194,22 +194,22 @@ doctor_cppcode <- function(stanc_ret,
     closing <- closing + mark
     return(closing)
   }
-  
+
   if (check_logical_scalar_first(drop_Eigen)) {
     mark <- grep("log_prob(Eigen::Matrix<", lines, fixed = TRUE)
     if (!detemplate) mark <- mark - 1L
     closing <- find_closing(lines, mark)
     lines <- lines[-c(mark:closing)]
-    mark <- grep("Eigen::Matrix<double,Eigen::Dynamic,1>& params_r,", 
+    mark <- grep("Eigen::Matrix<double,Eigen::Dynamic,1>& params_r,",
                  lines, fixed = TRUE)[1] - 1L
     closing <- find_closing(lines, mark)
     lines <- lines[-c(mark:closing)]
-    mark <- grep("Eigen::Matrix<double, Eigen::Dynamic, 1>& params_r,", 
+    mark <- grep("Eigen::Matrix<double, Eigen::Dynamic, 1>& params_r,",
                  lines, fixed = TRUE)[1] - 1L
     closing <- find_closing(lines, mark)
     lines <- lines[-c(mark:closing)]
   }
-  
+
   if (check_logical_scalar_first(drop_log_prob)) {
     mark <- grep("log_prob(", lines, fixed = TRUE)
     mark <- mark[!grepl("}", lines[mark])]
@@ -217,15 +217,16 @@ doctor_cppcode <- function(stanc_ret,
     closing <- find_closing(lines, mark)
     lines <- lines[-c(mark:closing)]
   }
-  
+
   necessary_headers <- c("#include <rstan/boost_random_R.hpp>",
-                         "#include <rstan/io/rlist_ref_var_context.hpp>")
+                         "#include <rstan/io/rlist_ref_var_context.hpp>",
+                         "#include <stan/model/model_base_crtp.hpp>")
   if (check_logical_scalar_first(drop_model_header)) {
     lines <- grep("#include <stan/model/model_header.hpp>", lines,
                   fixed = TRUE, invert = TRUE, value = TRUE)
     necessary_headers <- c(necessary_headers,
-                           ifelse(double_only, 
-                                  "#include <stan/math/prim/mat.hpp>",
+                           ifelse(double_only,
+                                  "#include <stan/math/prim.hpp>",
                                   "#include <stan/math/math.hpp>"),
                            "#include <stan/model/prob_grad.hpp>",
                            "#include <stan/io/array_var_context.hpp>",
@@ -241,9 +242,9 @@ doctor_cppcode <- function(stanc_ret,
       necessary_headers <- c(necessary_headers,
                              "#include <boost/random/additive_combine.hpp>",
                              "#include <boost/random/linear_congruential.hpp>")
-    
+
   }
-  
+
   if (check_logical_scalar_first(return_names)) {
     get_param_names <- c(
       "() const {",
@@ -258,13 +259,13 @@ doctor_cppcode <- function(stanc_ret,
       "  return param_names__;",
       "}")
     unconstrained_param_names <- sub("constrained_param_names",
-                                     "unconstrained_param_names", 
+                                     "unconstrained_param_names",
                                      constrained_param_names)
     add_methods$get_param_names_ <- get_param_names
     add_methods$constrained_param_names_ <- constrained_param_names
     add_methods$unconstrained_param_names_ <- unconstrained_param_names
   }
-  
+
   if (check_logical_scalar_first(return_dims)) {
     get_dims <- c(
       "() const {",
@@ -274,7 +275,7 @@ doctor_cppcode <- function(stanc_ret,
       "}")
     add_methods$get_dims_ <- get_dims
   }
-  
+
   if (!isTRUE(use_R_PRNG)) {
     set_Boost_seed <- c(
       "(const unsigned int seed) const {",
@@ -283,7 +284,7 @@ doctor_cppcode <- function(stanc_ret,
       "}")
     add_methods$set_Boost_seed <- set_Boost_seed
   }
-  
+
   if (!drop_log_prob) { # this is easily exportable to R
     log_prob <- if (detemplate) c(
       "(std::vector<double>& params_r__) const {",
@@ -294,10 +295,10 @@ doctor_cppcode <- function(stanc_ret,
         "  std::vector<int> params_i__;",
         "  return log_prob<>(params_r__, params_i__, pstream__);",
         "}")
-          
+
     add_methods$log_prob_ <- log_prob
   }
-  
+
   if (check_logical_scalar_first(add_gradient_method)) {
     if (drop_log_prob)
       stop("if 'add_gradient_method' is TRUE, 'drop_log_prob' must be FALSE")
@@ -317,7 +318,7 @@ doctor_cppcode <- function(stanc_ret,
   }
 
   if (check_logical_scalar_first(add_hessian_method)) {
-    if (drop_log_prob) 
+    if (drop_log_prob)
       stop("if 'add_gradient_method' is TRUE, 'drop_log_prob' must be FALSE")
     if (detemplate)
       stop("if 'add_gradient_method' is TRUE, 'detemplate' must be FALSE")
@@ -326,7 +327,7 @@ doctor_cppcode <- function(stanc_ret,
       "  std::vector<int> params_i__;",
       "  std::vector<double> grad_fx;",
       "  std::vector<double> hess_fx;",
-      paste0("  auto stan::model::grad_hess_log_prob<propto__, jacobian__>(", 
+      paste0("  auto stan::model::grad_hess_log_prob<propto__, jacobian__>(",
              "this, params_r__, params_i__, grad_fx, hess_fx, pstream__);"),
       "  return hess_fx;",
       "}")
@@ -334,9 +335,9 @@ doctor_cppcode <- function(stanc_ret,
     necessary_headers <- c(necessary_headers,
                            "#include <stan/model/grad_hess_log_prob.hpp>")
   }
-  
+
   if (check_logical_scalar_first(add_hessian_times_gradient_method)) {
-    if (drop_log_prob) 
+    if (drop_log_prob)
       stop("if 'add_hessian_times_gradient_method' is TRUE, 'drop_log_prob' must be FALSE")
     if (detemplate)
       stop("if 'add_hessian_times_gradient_method' is TRUE, 'detemplate' must be FALSE")
@@ -345,7 +346,7 @@ doctor_cppcode <- function(stanc_ret,
       "  std::vector<int> params_i__;",
       "  std::vector<double> grad_fx;",
       "  std::vector<double> hess_fx;",
-      paste0("  auto stan::model::grad_hess_log_prob<propto__, jacobian__>(", 
+      paste0("  auto stan::model::grad_hess_log_prob<propto__, jacobian__>(",
              "this, params_r__, params_i__, grad_fx, hess_fx, pstream__);"),
              "  return (hess_fx.selfadjointView<Eigen::Lower>() * grad_fx).eval();",
       "}")
@@ -354,9 +355,9 @@ doctor_cppcode <- function(stanc_ret,
       necessary_headers <- c(necessary_headers,
                              "#include <stan/model/grad_hess_log_prob.hpp>")
   }
-  
+
   if (check_logical_scalar_first(add_newton_step)) {
-    if (isTRUE(drop_log_prob)) 
+    if (isTRUE(drop_log_prob))
       stop("if 'add_newton_step' is TRUE, 'drop_log_prob' must be FALSE")
     newton_step <- c(
       "(std::vector<double> params_r__) {",
@@ -366,10 +367,10 @@ doctor_cppcode <- function(stanc_ret,
       "  return params_r__;",
       "}")
     add_methods$newton_step <- newton_step
-    necessary_headers <- c(necessary_headers, 
+    necessary_headers <- c(necessary_headers,
                            "#include <stan/services/optimization/newton_step.hpp>")
   }
-  
+
   make_sig_bod <- function(sig, friend) {
     if (detemplate) {
       start <- if (friend) "(this, " else "("
@@ -410,12 +411,12 @@ doctor_cppcode <- function(stanc_ret,
       sig <- "() {"
       bod <- paste0("return ", namespace_name, "::", method_name, "(); }")
     }
-    return(list(sig = sig, bod = bod))    
+    return(list(sig = sig, bod = bod))
   }
-  
-  lines <- gsub("Eigen::Matrix<double, Eigen::Dynamic, 1>", 
+
+  lines <- gsub("Eigen::Matrix<double, Eigen::Dynamic, 1>",
                 "Eigen::VectorXd", lines, fixed = TRUE)
-  lines <- gsub("Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic>", 
+  lines <- gsub("Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic>",
                 "Eigen::MatrixXd", lines, fixed = TRUE)
 
   mark <- grep("^namespace .* \\{$", lines)
@@ -423,8 +424,6 @@ doctor_cppcode <- function(stanc_ret,
   namespace_name <- sub(" {", "", namespace_name, fixed = TRUE)
   if (check_logical_scalar_first(methods_for_user_defined_functions)) {
     mark <- grep(paste0("^", valid, "+\\("), lines)
-    if (length(mark) == 0L)
-      stop("'methods_for_user_defined_functions' is TRUE but no functions found")
     for (i in rev(mark)) {
       end <- i
       while (!grepl("{", lines[end], fixed = TRUE)) end <- end + 1L
@@ -432,12 +431,12 @@ doctor_cppcode <- function(stanc_ret,
       method_name <- sub(paste0("^(", valid, "+)\\(.*$"), "\\1", sig)
       sig <- sub(method_name, "", sig, fixed = TRUE)
       sig_bod <- make_sig_bod(sig, friend = FALSE)
-      if (!detemplate) 
+      if (!detemplate)
         sig_body$sig <- gsub("T[[:digit:]]+__", "double", sig_bod$sig)
       add_methods[[method_name]] <- c(sig_bod$sig, sig_bod$bod)
     }
   }
-  
+
   if (length(friends) > 0L) {
     mark <- grep(paste0("^", valid, "+\\(.*\\);$"), lines)
     if (length(mark) == 0L)
@@ -455,16 +454,16 @@ doctor_cppcode <- function(stanc_ret,
       friends_list[[method_name]] <- sig
     }
   }
-  
+
   for (i in seq_along(add_methods)) {
     mark <- grep("^}; // model$", lines) - 1L
     method <- add_methods[[i]]
     lines <- append(lines, after = mark,
-                    values = c(paste0(four_spaces, "auto ", 
-                                      names(add_methods)[i], method[1]), 
+                    values = c(paste0(four_spaces, "auto ",
+                                      names(add_methods)[i], method[1]),
                                paste0(four_spaces, four_spaces, method[-1])))
   }
-  
+
   if (length(friends)) {
     mark <- grep("^}; // model$", lines) - 1L
     lines <- append(lines, values = "friend:", after = mark)
@@ -472,8 +471,8 @@ doctor_cppcode <- function(stanc_ret,
       mark <- grep("^}; // model$", lines) - 1L
       method <- friends_list[[i]]
       lines <- append(lines, after = mark,
-                      values = c(paste0(four_spaces, "auto ", 
-                                        names(friends_list)[i], method[1]), 
+                      values = c(paste0(four_spaces, "auto ",
+                                        names(friends_list)[i], method[1]),
                                  paste0(four_spaces, four_spaces, method[-1])))
     }
   }
@@ -481,41 +480,39 @@ doctor_cppcode <- function(stanc_ret,
   # do not create base_rng__ in ctor_body
   mark <- grep("boost::ecuyer1988 base_rng__ =", lines, fixed = TRUE)
   lines <- lines[-c(mark:(mark + 2L))]
-  
+
   # deal with constructor
-  mark <- grep(paste0("^class[[:space:]]+", 
-                      "[ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz]", 
-                      valid, "*[[:space:]]*: public prob_grad \\{"), lines)
-  class_name <- sub("^class (.*) : public prob_grad \\{", "\\1", lines[mark])
-  lines <- append(lines, after = mark,
+  mark <- grep("^class[[:space:]]+", lines)
+  class_name <- sub("^class (.*)", "\\1", lines[mark])
+  lines <- append(lines, after = mark + 1L,
                   values = c("protected:", unlist(protected)))
   lines <- append(lines, after = mark - 1L,
                   values = includes_for_user_defined_functions)
-  mark <- grep(paste0(class_name, "(stan::io::var_context& context__,"), 
+  mark <- grep(paste0(class_name, "(stan::io::var_context& context__,"),
                lines, fixed = TRUE)[1]
   closing <- find_closing(lines, mark)
   lines <- lines[-c(mark:closing)]
-  mark <- grep(paste0(class_name, "(stan::io::var_context& context__,"), 
+  mark <- grep(paste0(class_name, "(stan::io::var_context& context__,"),
                lines, fixed = TRUE)[1]
   closing <- find_closing(lines, mark)
   lines <- lines[-c(mark:closing)]
   if (default_constructor) {
-    mark <- grep("void ctor_body(stan::io::var_context& context__,", 
+    mark <- grep("void ctor_body(stan::io::var_context& context__,",
                  lines, fixed = TRUE)
     closing <- find_closing(lines, mark)
     lines <- lines[-c(mark:closing)]
     ctor <- paste0(four_spaces, class_name, "() : prob_grad(0) { }")
   } else {
-    ctor <- c(paste0(four_spaces, class_name, 
-                     "(rstan::io::rlist_ref_var_context context__) ",
-                     ": prob_grad(0) {"), 
+    ctor <- c(paste0(four_spaces, class_name,
+                     "(rstan::io::rlist_ref_var_context& context__) ",
+                     ": model_base_crtp(0) {"),
               paste0(four_spaces, four_spaces,
                      "ctor_body(context__, 0, ", pstream__, ");"),
               paste0(four_spaces, "}"))
   }
   mark <- grep("^public:", lines)[1L + make_data_public]
   lines <- append(lines, values = ctor, after = mark)
-  lines <- append(lines, after = 1L, c(necessary_headers, 
+  lines <- append(lines, after = 1L, c(necessary_headers,
                                        add_toplevel_headers))
 
   if (length(add_license) == 1L) {
@@ -524,7 +521,7 @@ doctor_cppcode <- function(stanc_ret,
       stop("'add_license' not among license abbreviations known to R")
     lines < c("/*", readLines(license), "*/", "", lines)
   }
-  
+
   stanc_ret$cppcode <- lines
   stanc_ret$methods <- add_methods
   stanc_ret$friends <- if (length(friends)) friends_list
