@@ -9,7 +9,6 @@
 #include <algorithm>
 #include <rstan/io/r_ostream.hpp>
 #include <stan/version.hpp>
-#include <boost/lexical_cast.hpp>
 
 namespace rstan {
 
@@ -46,7 +45,7 @@ namespace rstan {
 
     inline unsigned int sexp2seed(SEXP seed) {
       if (TYPEOF(seed) == STRSXP)
-        return boost::lexical_cast<unsigned int>(Rcpp::as<std::string>(seed));
+        return std::stoull(Rcpp::as<std::string>(seed));
       return Rcpp::as<unsigned int>(seed);
     }
 
