@@ -16,16 +16,11 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // #include <stan/mcmc/chains.hpp>
-#include <stan/math/prim/mat/fun/mean.hpp>
-#include <stan/math/prim/mat/fun/sum.hpp>
-#include <stan/math/prim/mat/fun/variance.hpp>
-#include <stan/math/prim/mat/fun/autocorrelation.hpp>
-#include <stan/math/prim/mat/fun/autocovariance.hpp>
+#include <stan/math/prim.hpp>
 
 #include <boost/accumulators/accumulators.hpp>
 #include <boost/accumulators/statistics/stats.hpp>
 #include <boost/accumulators/statistics/mean.hpp>
-#include <boost/lexical_cast.hpp>
 #include <boost/random/additive_combine.hpp> // L'Ecuyer RNG
 #include <boost/random/uniform_int_distribution.hpp>
 #include <fstream>
@@ -55,7 +50,7 @@ private:
   
   inline unsigned int sexp2seed(SEXP seed) {
     if (TYPEOF(seed) == STRSXP)
-      return boost::lexical_cast<unsigned int>(Rcpp::as<std::string>(seed));
+      return std::stoull(Rcpp::as<std::string>(seed));
     return Rcpp::as<unsigned int>(seed);
   }
   
